Package: areal
Type: Package
Title: Areal Weighted Interpolation
Version: 0.1.8
Authors@R: c(
    person("Christopher", "Prener", , "chris.prener@gmail.com", c("aut", "cre"),
    comment = c(ORCID = "0000-0002-4310-9888")),
    person("Charlie","Revord", , "charlie.revord@slu.edu", c("aut")),
    person("Branson", "Fox", ,"branson.fox@slu.edu", c("aut"),
    comment = c(ORCID = "0000-0002-4361-2811"))
    )
Description: A pipeable, transparent implementation of areal weighted interpolation
    with support for interpolating multiple variables in a single function call.
    These tools provide a full-featured workflow for validation and estimation
    that fits into both modern data management (e.g. tidyverse) and spatial 
    data (e.g. sf) frameworks.
Depends: R (>= 3.4)
License: GPL-3
URL: https://chris-prener.github.io/areal/
BugReports: https://github.com/chris-prener/areal/issues
Encoding: UTF-8
LazyData: true
Imports: dplyr, glue, purrr, rlang, sf
RoxygenNote: 7.1.2
Suggests: knitr, rmarkdown, testthat, covr
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2022-05-31 00:46:59 UTC; chris
Author: Christopher Prener [aut, cre] (<https://orcid.org/0000-0002-4310-9888>),
  Charlie Revord [aut],
  Branson Fox [aut] (<https://orcid.org/0000-0002-4361-2811>)
Maintainer: Christopher Prener <chris.prener@gmail.com>
Repository: CRAN
Date/Publication: 2022-05-31 07:40:06 UTC
Built: R 4.6.0; ; 2026-04-28 23:15:22 UTC; unix
