Package: areal
Type: Package
Title: Areal Weighted Interpolation
Version: 0.1.8.9000
Authors@R: c(
    person("Christopher", "Prener", , "chris.prener@gmail.com", c("aut", "cre"),
    comment = c(ORCID = "0000-0002-4310-9888")),
    person("Charlie","Revord", , "charlie.revord@slu.edu", c("aut")),
    person("Branson", "Fox", ,"branson.fox@slu.edu", c("aut"),
    comment = c(ORCID = "0000-0002-4361-2811"))
    )
Description: A pipeable, transparent implementation of areal weighted interpolation
    with support for interpolating multiple variables in a single function call.
    These tools provide a full-featured workflow for validation and estimation
    that fits into both modern data management (e.g. tidyverse) and spatial 
    data (e.g. sf) frameworks.
Depends: R (>= 3.4)
License: GPL-3
URL: https://chris-prener.github.io/areal/
BugReports: https://github.com/chris-prener/areal/issues
Encoding: UTF-8
LazyData: true
Imports:
  dplyr,
  glue,
  purrr,
  rlang,
  sf
RoxygenNote: 7.1.2
Suggests:
  knitr,
  rmarkdown,
  testthat,
  covr
VignetteBuilder: knitr
