# Generated by roxygen2: do not edit by hand

export(ar_tessellate)
export(ar_validate)
export(aw_aggregate)
export(aw_calculate)
export(aw_interpolate)
export(aw_intersect)
export(aw_preview_weights)
export(aw_total)
export(aw_verify)
export(aw_weight)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarize)
importFrom(glue,glue)
importFrom(rlang,":=")
importFrom(rlang,enquo)
importFrom(rlang,quo)
importFrom(rlang,quo_name)
importFrom(rlang,sym)
importFrom(sf,st_area)
importFrom(sf,st_collection_extract)
importFrom(sf,st_crs)
importFrom(sf,st_geometry)
importFrom(sf,st_intersection)
importFrom(sf,st_is_longlat)
importFrom(sf,st_make_grid)
importFrom(sf,st_sf)
importFrom(sf,st_union)
