---
name: Bug report
about: Create a report to help me address a problem

---

**Before you open your issue:**
* All issues and contributions are covered by the [Code of Conduct](/.github/CODE_OF_CONDUCT.md)
* Please check out the [Contribution guidelines](/.github/CONTRIBUTING.md)

**Describe the bug**
A clear and concise description of what the bug is.

**Expected behavior**
A clear and concise description of what you expected to happen.

**To Reproduce**
Please include a minimal reproducible example (AKA a reprex). If you've never
heard of a [reprex](http://reprex.tidyverse.org/) before, start by reading
<https://www.tidyverse.org/help/#reprex>. When you create your reprex, please use 
a data set available in a package.

```r
# inset reprex here
```

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. macOS]
 - Version of R [e.g. v3.5.1]
 - Version of RStudio [e.g. v1.1.453]

**Additional context**
Add any other context about the problem here.
