**Before you open your pull request:**

* All issues and contributions are covered by the [Code of Conduct](/.github/CODE_OF_CONDUCT.md)
* Please check out the [Contribution guidelines](/.github/CONTRIBUTING.md)

**Describe your contribution** Please describe the changes you are suggestion. If these are in response to specific issues, please link to them by using the `#15` syntax where `15` is the issue number.
