---
name: Feature request
about: Suggest an idea for this project

---

**Before you open your issue:**
* All issues and contributions are covered by the [Code of Conduct](/.github/CODE_OF_CONDUCT.md)
* Please check out the [Contribution guidelines](/.github/CONTRIBUTING.md)

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Provide a reprex**
Please include a minimal reproducible example (AKA a reprex). If you've never
heard of a [reprex](http://reprex.tidyverse.org/) before, start by reading
<https://www.tidyverse.org/help/#reprex>. When you create your reprex, please use 
a data set available in a package.

```r
# inset reprex here
```

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.
