---
name: Other inquiry
about: Ask a question or give me some feedback

---

**Before you open your issue:**
* All issues and contributions are covered by the [Code of Conduct](/.github/CODE_OF_CONDUCT.md)
* Please check out the [Contribution guidelines](/.github/CONTRIBUTING.md)

**Is your inquiry related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Provide a reprex**
Please include a minimal reproducible example (AKA a reprex). If you've never
heard of a [reprex](http://reprex.tidyverse.org/) before, start by reading
<https://www.tidyverse.org/help/#reprex>. When you create your reprex, please use a 
data set available in a package.

```r
# inset reprex here
```
